<?php

/**
 * Amazon settings 
 */
function aws_amazon_admin_settings_form($form, &$form_state) {
  if (!file_exists('sites/all/libraries/AWSSDKforPHP/sdk.class.php')) {
    form_set_error('', t('AWS PHP Library not found. Download and place the library in sites/all/libraries/AWSSDKforPHP/sdk.class.php'));
  }
  global $base_url;
  //generate a unique URL per site that cannot be faked.
  $accesskey = variable_get('aws_amazon_access_key', '');
  if (!empty($accesskey)) {
    $regions = _aws_amazon_get_regions();
    if (empty($regions)) {
      $regions = array('Failed to connect to Amazon.');
    }
    
    $token = hash('sha1', $base_url . $accesskey);
    $form['amazon_cron_url_link'] = array(
      '#type' => 'markup',
      '#markup' => t('URL for usage in cron %url. Note menu cache may need to be flushed.', array('%url' => url('aws-amazon-cron/' . $token, array('absolute' => TRUE)))), 
    );
    
    //check selected regions against volumes
    _aws_amazon_validate_regions($regions);
  }

  $form['aaccess'] = array(
    '#type' => 'fieldset',
    '#title' => t('AWS Access Configuration'),
    '#collapsible' => TRUE,
  );
  $key = variable_get('aws_amazon_isecret_key', '');
  if (!empty($key)) {
    if (strpos($key, 'delete') !== FALSE) {
      variable_del('aws_amazon_secret_key');
    }
    else {
      variable_set('aws_amazon_secret_key', $key);
    }
    variable_del('aws_amazon_isecret_key');
  }
  $form['aaccess']['aws_amazon_isecret_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon Secret Key'),
    '#attributes' => array('autocomplete' => 'off'),
    '#description' => t('Set the value to change the existing value. Saved values are not shown. To delete the saved value enter %del', array('%del' => 'delete')),
  );
  $key = variable_get('aws_amazon_iaccess_key', '');
  if (!empty($key)) {
    if (strpos($key, 'delete') !== FALSE) {
      variable_del('aws_amazon_access_key');
    }
    else {
      variable_set('aws_amazon_access_key', $key);
    }
    cache_clear_all('', 'cache_menu');
    variable_del('aws_amazon_iaccess_key');
  }
  $form['aaccess']['aws_amazon_iaccess_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Amazon Access Key'),
    '#attributes' => array('autocomplete' => 'off'),
    '#description' => t('Set the value to change the existing value. Saved values are not shown. To delete the saved value enter %del', array('%del' => 'delete')),
  );
  $form['abackups'] = array(
    '#type' => 'fieldset',
    '#title' => t('EC2 Backup Configuration'),
    '#collapsible' => TRUE,
  );
  $form['abackups']['aws_amazon_log'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Logging'),
    '#default_value' => variable_get('aws_amazon_log', 0),
    '#description' => t('If this is selected then all actions will be logged in watchdog, otherwise only errors are logged'),
  );
  $form['abackups']['aws_amazon_backup_cron'] = array(
    '#type' => 'radios',
    '#title' => t('Run Backup and Clean in Cron'),
    '#options' => array(0 => t('Do not run in cron'), 1 => t('Run on each cron run'), 2 => t('Once a day'),),
    '#default_value' => variable_get('aws_amazon_backup_cron', 0),
    '#description' => t('Both the options on Drupal cron run')
  );
  $form['abackups']['aws_amazon_backup_allow'] = array(
    '#type' => 'checkbox',
    '#title' => t('Create backups'),
    '#default_value' => variable_get('aws_amazon_backup_allow', 1),
    '#description' => t('If this is deselected, then no backup will be created'),
  );
  $form['abackups']['aws_amazon_backup_type'] = array(
    '#type' => 'radios',
    '#title' => t('Select Number of Backups to Retain'),
    '#options' => array(0 => t('All Backup'), 1 => t('Number of Days'), 2 => t('Number of Backups')),
    '#default_value' => variable_get('aws_amazon_backup_type', 0),
  );
  $form['abackups']['aws_amazon_backup_no'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of Backups'),
    '#element_validate' => array('aws_amazon_element_validate_numeric'),
    '#description' => t('Number of backups to retain. At least 1 backup will be maintained.'),
    '#default_value' => variable_get('aws_amazon_backup_no', 0),
  );
  $form['abackups']['aws_amazon_backup_vols'] = array(
    '#type' => 'textarea',
    '#title' => t('Volume IDs'),
    '#description' => t('Enter the volume IDs to backup / delete. Enter one per line. If volumes are in different region specify region|volume. Available regions are !regions', array('!regions' => implode(', ', $regions))),
    '#default_value' => variable_get('aws_amazon_backup_vols', ''),
  );
  $form['aws_amazon_debug'] = array(
    '#type' => 'checkbox',
    '#title' => t('Test Run Only'),
    '#default_value' => variable_get('aws_amazon_debug', 1),
    '#description' => t('If this is selected then no actual operation is performed. The actions are logged in watchdog for review. Deselect this for actual operation to be performed.'),
  );
  return system_settings_form($form);
}

function _aws_amazon_validate_regions($regions) {
  $volumes = explode("\n", variable_get('aws_amazon_backup_vols', ''));
  $vol_regions = array();
  $endpoints = array_flip($regions);
  foreach ($volumes as $vol) {
    if (strpos($vol, '|') !== FALSE) {
      $token = explode('|', $vol);
      $vol_regions[trim($token[0])] = $endpoints[trim($token[0])];
    }
  }
  variable_set('aws_amazon_regions', $vol_regions);
}
